import http from 'http';
import { Vivid } from './lib/vivid';

const server = http.createServer((req: http.IncomingMessage, res) => {
  const { url, method } = req;
  if (!url) {
    res.statusCode = 400;
    res.end('Invalid request');
    return;
  }

  const request = new URL(url, `http://127.0.0.1`);
  const { pathname } = request;
  if (pathname === '/favicon.ico') {
    return;
  }
  if (pathname.startsWith('/api')) {
    res.setHeader('Content-Type', 'application/json');
    res.end(JSON.stringify({ message: 'Hello World' }));
    return;
  }
  //
  if (method !== 'GET') {
    res.statusCode = 405;
    res.end('Method not allowed');
    return;
  }
  const vivid = new Vivid();
  const accept = req.headers['accept'];
  if (accept && accept.includes('text/html')) {
    res.setHeader('Content-Type', 'text/html');
    res.end(vivid.getHTML());
    return;
  }
  if (accept && accept.includes('application/json')) {
    res.setHeader('Content-Type', 'application/javascript');
    res.end(`console.log(new Date())`);
    return;
  }
  res.statusCode = 406;
  res.end('Not Acceptable');
});

const port = 3006;
server.listen(port, () => {
  console.log(`Server is running on http://localhost:${port}`);
});
